@@ -154,3 +154,9 @@ class ManabaReportDetails(ManabaModel):
             Optional[ManabaTaskStatus]: 状態
         """
         return self._status
+
+    def __str__(self) -> str:
+        return "ManabaReportDetails{course_id=%s,report_id=%s,title=%s,description=%s,reception_start_time=%s,reception_end_time=%s,portfolio_type=%s,result_view_type=%s,student_resubmit_type=%s,status=%s}" % (
+            self._course_id, self._report_id, self._title, self._description, self._reception_start_time,
+            self._reception_end_time, self._portfolio_type, self._result_view_type, self._student_resubmit_type,
+            self._status)
